from setuptools import setup

setup(
  name = 'AsyncPQ',
  packages = ['AsyncPQ'], # this must be the same as the name above
  version = '0.41',
  description = 'Low overhead, dead simple Asyncronous Priority Queue',
  author = 'Michael Usachenko',
  author_email = 'meu2@illinois.edu',
  url = 'https://github.com/themichaelusa/AsyncPQ', # use the URL to the github repo
  download_url = 'https://github.com/themichaelusa/AsyncPQ/archive/0.41.tar.gz', # I'll explain this in a second
  keywords = ['async', 'priority', 'queue'], # arbitrary keywords
  classifiers = [],
)